# open-buildings

[![image](https://img.shields.io/pypi/v/open-buildings.svg)](https://pypi.python.org/pypi/open-buildings)
[![image](https://img.shields.io/conda/vn/conda-forge/open-buildings.svg)](https://anaconda.org/conda-forge/open-buildings)

**Tools for working with open building datasets**

-   Free software: Apache Software License 2.0
-   Documentation: https://opengeos.github.io/open-buildings

## Features

-   TODO
